==> kdepim-addons-16.07.80.tar.xz: kdepim-addons-16.07.80/kmail/editorsendcheckplugins/checkbeforesend/checkbeforesendinterface.h <==
/*
   Copyright (C) 2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CHECKBEFORESENDINTERFACE_H
#define CHECKBEFORESENDINTERFACE_H

#include <MessageComposer/PluginEditorCheckBeforeSendInterface>
namespace KIdentityManagement
{
class IdentityManager;
}
class CheckBeforeSendInterface : public MessageComposer::PluginEditorCheckBeforeSendInterface
{
    Q_OBJECT
public:
    explicit CheckBeforeSendInterface(QObject *parent = Q_NULLPTR);
    ~CheckBeforeSendInterface();

    bool exec(const MessageComposer::PluginEditorCheckBeforeSendParams &params) Q_DECL_OVERRIDE;

public Q_SLOTS:
    void reloadConfig() Q_DECL_OVERRIDE;
private:
    KIdentityManagement::IdentityManager *mIdentityManager;
    bool mSendPlainText;
    bool mCheckMailTransport;
    bool mCheckDuplicateEmails;
    bool mCheckSendAttachments;
};

#endif // CHECKBEFORESENDINTERFACE_H

==> kdepim-addons-18.11.80.tar.xz: kdepim-addons-18.11.80/kmail/editorsendcheckplugins/checkbeforesend/checkbeforesendinterface.h <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef CHECKBEFORESENDINTERFACE_H
#define CHECKBEFORESENDINTERFACE_H

#include <MessageComposer/PluginEditorCheckBeforeSendInterface>
class CheckBeforeSendInterface : public MessageComposer::PluginEditorCheckBeforeSendInterface
{
    Q_OBJECT
public:
    explicit CheckBeforeSendInterface(QObject *parent = nullptr);
    ~CheckBeforeSendInterface() override;

    bool exec(const MessageComposer::PluginEditorCheckBeforeSendParams &params) override;

public Q_SLOTS:
    void reloadConfig() override;
private:
    bool mSendPlainText = false;
    bool mCheckMailTransport = false;
    bool mCheckDuplicateEmails = false;
    bool mCheckSendAttachments = false;
};

#endif // CHECKBEFORESENDINTERFACE_H
